==> virtualbox_5.2.8-dfsg.orig.tar.xz: VirtualBox-5.2.8/src/VBox/Runtime/common/string/RTStrStartsWith.cpp <==
/* $Id: RTStrStartsWith.cpp $ */
/** @file
 * IPRT - String starts with predicate.
 */

/*
 * Copyright (C) 2006-2017 Oracle Corporation
 *
 * This file is part of VirtualBox Open Source Edition (OSE), as
 * available from http://www.virtualbox.org. This file is free software;
 * you can redistribute it and/or modify it under the terms of the GNU
 * General Public License (GPL) as published by the Free Software
 * Foundation, in version 2 as it comes in the "COPYING" file of the
 * VirtualBox OSE distribution. VirtualBox OSE is distributed in the
 * hope that it will be useful, but WITHOUT ANY WARRANTY of any kind.
 *
 * The contents of this file may alternatively be used under the terms
 * of the Common Development and Distribution License Version 1.0
 * (CDDL) only, as it comes in the "COPYING.CDDL" file of the
 * VirtualBox OSE distribution, in which case the provisions of the
 * CDDL are applicable instead of those of the GPL.
 *
 * You may elect to license modified versions of this file under the
 * terms and conditions of either the GPL or the CDDL or both.
 */


/*********************************************************************************************************************************
*   Header Files                                                                                                                 *
*********************************************************************************************************************************/
#define LOG_GROUP RTLOGGROUP_STRING
#include <iprt/string.h>
#include "internal/iprt.h"


RTDECL(int) RTStrStartsWith(const char *pszString, const char *pszStart)
{
    if (pszString)
    {
        if (*pszString == *pszStart)
        {
            size_t cchStart = strlen(pszStart);
            if (strncmp(pszString, pszStart, cchStart) == 0)
                return true;
        }
    }
    return false;
}

==> virtualbox_6.1.0-dfsg.orig.tar.xz: VirtualBox-6.1.0/src/VBox/Runtime/common/string/RTStrStartsWith.cpp <==
/* $Id: RTStrStartsWith.cpp $ */
/** @file
 * IPRT - String starts with predicate.
 */

/*
 * Copyright (C) 2006-2019 Oracle Corporation
 *
 * This file is part of VirtualBox Open Source Edition (OSE), as
 * available from http://www.virtualbox.org. This file is free software;
 * you can redistribute it and/or modify it under the terms of the GNU
 * General Public License (GPL) as published by the Free Software
 * Foundation, in version 2 as it comes in the "COPYING" file of the
 * VirtualBox OSE distribution. VirtualBox OSE is distributed in the
 * hope that it will be useful, but WITHOUT ANY WARRANTY of any kind.
 *
 * The contents of this file may alternatively be used under the terms
 * of the Common Development and Distribution License Version 1.0
 * (CDDL) only, as it comes in the "COPYING.CDDL" file of the
 * VirtualBox OSE distribution, in which case the provisions of the
 * CDDL are applicable instead of those of the GPL.
 *
 * You may elect to license modified versions of this file under the
 * terms and conditions of either the GPL or the CDDL or both.
 */


/*********************************************************************************************************************************
*   Header Files                                                                                                                 *
*********************************************************************************************************************************/
#define LOG_GROUP RTLOGGROUP_STRING
#include <iprt/string.h>
#include "internal/iprt.h"


RTDECL(bool) RTStrStartsWith(const char *pszString, const char *pszStart)
{
    if (pszString)
    {
        if (*pszString == *pszStart)
        {
            size_t cchStart = strlen(pszStart);
            if (strncmp(pszString, pszStart, cchStart) == 0)
                return true;
        }
    }
    return false;
}
